@@ -1,11 +1,12 @@
 # helpers for data
 
 getdata <- function(dir, name) {
-	readRDS(paste("testdata/", dir, "/", name, ".rds", sep = ""))
+    readRDS(testthat::test_path("testdata", dir, paste0(name, ".rds")))
 }
 
+# this is honestly quite hacky, will rm in the future
 sourcedata <- function(dir, name) {
-	source(paste("testdata/", dir, "/", name, ".R", sep = ""))
+    source(testthat::test_path("testdata", dir, paste0(name, ".R")))
 }
 
 # hacky trick for testing with no messages in the terminal
@@ -13,15 +14,15 @@ sourcedata <- function(dir, name) {
 quietly <- function(e) suppressMessages(capture.output(e))
 
 quietly_test_that <- function(desc, code) {
-	test_that(desc, {quietly(code)})
+    testthat::test_that(desc, {quietly(code)})
 }
 
 # skippers
 
 skip_if_r_version_leq <- function(version) {
-	skip_if(is_curr_r_version_leq(version))
+    testthat::skip_if(is_curr_r_version_leq(version))
 }
 
 is_curr_r_version_leq <- function(version) {
-	package_version(R.version) <= package_version(version)
+    package_version(R.version) <= package_version(version)
 }
